translate.lang.zh

Package translate :: Package lang :: Module zh |
[hide private]
[frames] | no frames]

# Module zh

source code

This module represents Chinese language. (Both tradisional and simplified)

For more information, see http://en.wikipedia.org/wiki/Chinese_language

Classes | [hide private]
| zh This class represents Chinese.

Variables | [hide private]
| __package__ = ``'``translate.lang``'``

Imports: re, common